@@ -1,5 +1,5 @@
 -- HOBlockCipher.hs: abstraction for the different BlockCipher classes, plus crazy CFB mode stuff
--- Copyright © 2016  Clint Adams
+-- Copyright © 2016-2024  Clint Adams
 -- This software is released under the terms of the Expat license.
 -- (See the LICENSE file).
 {-# LANGUAGE PackageImports #-}
@@ -8,7 +8,7 @@ module Codec.Encryption.OpenPGP.Internal.HOBlockCipher
   ( HOBlockCipher(..)
   ) where
 
-import qualified "cryptonite" Crypto.Cipher.Types as CCT
+import qualified "crypton" Crypto.Cipher.Types as CCT
 
 import qualified Data.ByteString as B
 
