@@ -1,5 +1,5 @@
 -- Serialize.hs: OpenPGP (RFC4880) serialization (using cereal)
--- Copyright © 2012-2020  Clint Adams
+-- Copyright © 2012-2025  Clint Adams
 -- This software is released under the terms of the Expat license.
 -- (See the LICENSE file).
 module Codec.Encryption.OpenPGP.Serialize
@@ -307,8 +307,10 @@ getSigSubPacket = do
         hash <- getLazyByteString (l - 3)
         return $ SigSubPacket crit (SignatureTarget pka ha hash)
       | pt == 32 = do
-        sp <- get :: Get SignaturePayload
-        return $ SigSubPacket crit (EmbeddedSignature sp)
+        spbs <- getLazyByteString (l - 1)
+        case runGetOrFail get spbs of
+            Left (_, _, e) -> fail ("embedded signature subpacket " ++ e)
+            Right (_, _, sp) -> return $ SigSubPacket crit (EmbeddedSignature sp)
       | pt == 33 = do
         kv <- getWord8
         fp <-
