@@ -1,5 +1,5 @@
 -- Types.hs: OpenPGP (RFC4880) data types
--- Copyright © 2012-2016  Clint Adams
+-- Copyright © 2012-2024  Clint Adams
 -- This software is released under the terms of the Expat license.
 -- (See the LICENSE file).
 module Codec.Encryption.OpenPGP.Types
@@ -7,7 +7,7 @@ module Codec.Encryption.OpenPGP.Types
   ) where
 
 import Codec.Encryption.OpenPGP.Types.Internal.Base as X
-import Codec.Encryption.OpenPGP.Types.Internal.CryptoniteNewtypes as X
+import Codec.Encryption.OpenPGP.Types.Internal.CryptonNewtypes as X
 import Codec.Encryption.OpenPGP.Types.Internal.PKITypes as X
 import Codec.Encryption.OpenPGP.Types.Internal.PacketClass as X
 import Codec.Encryption.OpenPGP.Types.Internal.Pkt as X
