@@ -30,6 +30,7 @@ import qualified Data.List.NonEmpty as NE
 import Data.Ord (comparing)
 import Data.Text (Text)
 import qualified Data.Text as T
+import Data.Time.Clock (UTCTime)
 import Data.Typeable (Typeable)
 import Data.Word (Word8)
 import Prettyprinter (Pretty(..), (<+>))
@@ -224,4 +225,14 @@ data Verification =
     , _verificationSignature :: SignaturePayload
     }
 
+data SOPVVerification =
+  SOPVVerification
+    { _sopvvDateStamp :: UTCTime
+    , _sopvvFingerprint :: TwentyOctetFingerprint
+    , _sopvvPrimaryFingerprint :: TwentyOctetFingerprint
+    , _sopvvMode :: String
+    , _sopvvDescription :: String
+    }
+
 $(makeLenses ''Verification)
+$(makeLenses ''SOPVVerification)
